/*
 * COPYRIGHT INFORMATION - DO NOT REMOVE
 *
 * This file is part of the MagicSpam (TM) Project and is
 * Copyright (c) LinuxMagic Inc. 2018-2021 All Rights Reserved
 *
 * This file contains Original Code as created by LinuxMagic Inc.
 *
 * The Original Code is distributed on an 'AS IS' basis,
 * WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESS OR IMPLIED, AND LINUXMAGIC
 * HEREBY DISCLAIMS ALL SUCH WARRANTIES, INCLUDING WITHOUT LIMITATION, ANY
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, QUIET
 * ENJOYMENT OR NON-INFRINGEMENT.
 *
 * Do NOT download, distribute, use or alter this software or file in any
 * way without express written permission from LinuxMagic Inc. or its parent
 * company Wizard Tower TechnoServices signed by an authorized company officer.
 *
 * Author(s): Deion Yu <deiony@linuxmagic.com>
 *
 * $Id: hour-stats.js 12603 2021-10-08 21:23:11Z deiony $
 */

function getHourlyLogs(hour)
{
    // sanity check
    if (typeof hour !== "number" || hour < 0 || hour > 23) {
        return;
    }

    // grab the hourly logsearch form in the page
    var form = document.getElementById('hourLogSearchForm');
    if (form === null) {
        return;
    }

    // set the form with the hour that the user clicked on
    form.ms_hour.value = hour;

    // set the form with whether to use yesterday or today log
    form.yesterday.value = isYesterday(hour);

    // set the form with the filter that the user selected, if any
    form.filter.value = getHourlyLogFilter();

    // XXX: Workaround for DirectAdmin Evolution Skin, will not affect anything else
    if (form.action.indexOf('?iframe=yes') != -1)  {
        form.action = form.action.split('?')[0];
    }

    // open a blank window and submit the form
    // NOTE: unless we are running in the MailEnable MMC context
    if (form.target != '') {
        window.open("", form.target);
    }
    form.submit();
}

function isYesterday(hour)
{
    // sanity check
    if (typeof hour !== "number" || hour < 0 || hour > 23) {
        return 0;
    }

    // grab all the hour rows in the page
    var hourRows = document.getElementsByClassName('hourlyStatDayRow');

    // use regex to find the leftmost time (index 23)
    var regex = /getHourlyLogs\((\d+)\)/g;
    var match = regex.exec(hourRows[0].getAttribute('onclick'));
    var leftTime = match[1];

    // calculate the rightmost time (index 0)
    var rightTime = leftTime == 0 ? 23 : (leftTime - 1) % 24;

    // we now also know the index for 12am
    var middleIndex = rightTime;

    // calculate the index of the selected hour
    var hourIndex = 0;
    if (hour > rightTime) {
        hourIndex = 23 - (hour - leftTime);
    } else {
        hourIndex = (rightTime - hour) % 24;
    }

    // determine whether the selected hour uses yesterday's log
    if (hourIndex > middleIndex) {
        return 1;
    }

    // otherwise, default to using today's log
    return 0;
}

function getHourlyLogFilter()
{
    var filter = 0;
    var hourlyLogFilters = [
        ['.hourlyStatHamBar',        1],
        ['.hourlyStatSpamBar',       6],
        ['.hourlyStatExemptBar',     8],
        ['.hourlyStatRatelimitBar', 16],
    ];
    var hourlyLogFilterSelectors = hourlyLogFilters.map(function(v) { return v[0]; });
    var hourlyLogFilterScores = hourlyLogFilters.map(function(v) { return v[1]; });

    // loop through all the stylesheets
    var c = 0;
    for (c = 0; c < document.styleSheets.length; c++) {
        // grab the CSS rules from the stylesheet
        var rules = new Array();
        if (document.styleSheets[c].cssRules) {
            rules = document.styleSheets[c].cssRules;
        } else if (document.styleSheets[c].rules) {
            rules = document.styleSheets[c].rules;
        }

        // loop through each selector in the CSS rules from the stylesheet
        var d = 0;
        for (d = 0; d < rules.length; d++) {
            // find the hourly log filter selectors
            var f = hourlyLogFilterSelectors.indexOf(rules[d].selectorText);
            if (f === -1) {
                continue;
            }

            // ignore hidden filter selectors
            if (rules[d].style.visibility == "hidden") {
                continue;
            }

            // store the filter score
            filter += hourlyLogFilterScores[f];
        }
    }

    return filter;

}
